@@ -273,18 +273,19 @@ gboolean tangle_signal_accumulator_non_null_handled(GSignalInvocationHint* ihint
 }
 
 static gboolean connect_signal_dynamically(GObject* object, const gchar* signal_name, const gchar* function_name, gpointer user_data, gboolean swapped, gboolean set_weak_notify) {
+	static GModule* module = NULL;
+
 	gboolean retvalue = FALSE;
-	GModule* module = NULL;
 	gpointer function_pointer;
 	TangleVault* vault;
 
 	g_return_val_if_fail(G_IS_OBJECT(object), FALSE);	
 	g_return_val_if_fail(signal_name != NULL, FALSE);
 	g_return_val_if_fail(function_name != NULL, FALSE);
-	
+
 	if (!g_signal_parse_name(signal_name, G_TYPE_FROM_INSTANCE(object), NULL, NULL, FALSE)) {
 		g_warning("No such signal: '%s'.", signal_name);
-	} else if (!g_module_supported() || !(module = g_module_open(NULL, 0))) {
+	} else if (!module && (!g_module_supported() || !(module = g_module_open(NULL, 0)))) {
 		g_warning("The current platform does not support modules.");
 	} else if (!g_module_symbol(module, function_name, (gpointer*)&function_pointer)) {
 		g_warning("No such function: '%s'", function_name);
@@ -302,9 +303,6 @@ static gboolean connect_signal_dynamically(GObject* object, const gchar* signal_
 			g_warning("Failed to connect a handler function '%s' for signal '%s'.", function_name, signal_name);
 		}
 	}
-	if (module) {
-		g_module_close(module);
-	}
 	
 	return retvalue;
 }
